====================
djangocms-page-image
====================

A DjangoCMS page extension providing a featured image and a teaser text.

Dependencies
============

* django-filer >= 1.2
* Django >= 1.8
* django-cms >= 3.1
* django-sekizai >= 0.4.2
* easy_thumbnails >= 1.0
